summaryrefslogtreecommitdiff
path: root/dbus/dbus-sysdeps-unix.c
diff options
context:
space:
mode:
authorRalf Habacker <ralf.habacker@freenet.de>2015-03-11 15:56:58 +0100
committerRalf Habacker <ralf.habacker@freenet.de>2015-03-11 15:56:58 +0100
commit40a6b6e815d9762221ac0c6e6bd11a53fde4b11b (patch)
tree4f7064f4b424a35f51789ecc7211f68a8b363b5f /dbus/dbus-sysdeps-unix.c
parentdfaf56e922d31c57d22149f15a7ded3e34e82d7f (diff)
downloaddbus-40a6b6e815d9762221ac0c6e6bd11a53fde4b11b.tar.gz
Revert "Rename _dbus_full_duplex_pipe() to more descriptive name _dbus_socketpair()."
This reverts commit ee0e15366c8b1ea196ad63a8376c8b5299279386.
Diffstat (limited to 'dbus/dbus-sysdeps-unix.c')
-rw-r--r--dbus/dbus-sysdeps-unix.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/dbus/dbus-sysdeps-unix.c b/dbus/dbus-sysdeps-unix.c
index ab7efc25..3f606712 100644
--- a/dbus/dbus-sysdeps-unix.c
+++ b/dbus/dbus-sysdeps-unix.c
@@ -3275,22 +3275,22 @@ _dbus_print_backtrace (void)
}
/**
* Creates pair of connect sockets (as in socketpair()).
* Sets both ends of the pair nonblocking.
*
* Marks both file descriptors as close-on-exec
*
* @param fd1 return location for one end
* @param fd2 return location for the other end
* @param blocking #TRUE if pair should be blocking
* @param error error return
* @returns #FALSE on failure (if error is set)
*/
dbus_bool_t
-_dbus_socketpair (int *fd1,
- int *fd2,
- dbus_bool_t blocking,
- DBusError *error)
+_dbus_full_duplex_pipe (int *fd1,
+ int *fd2,
+ dbus_bool_t blocking,
+ DBusError *error)
{
#ifdef HAVE_SOCKETPAIR
int fds[2];
@@ -3346,9 +3346,9 @@ _dbus_socketpair (int *fd1,
return TRUE;
#else
- _dbus_warn ("_dbus_socketpair() not implemented on this OS\n");
+ _dbus_warn ("_dbus_full_duplex_pipe() not implemented on this OS\n");
dbus_set_error (error, DBUS_ERROR_FAILED,
- "_dbus_socketpair() not implemented on this OS");
+ "_dbus_full_duplex_pipe() not implemented on this OS");
return FALSE;
#endif
}
@@ -3275,22 +3275,22 @@ _dbus_print_backtrace (void)
}
/**
- * Creates pair of connect sockets (as in socketpair()).
- * Sets both ends of the pair nonblocking.
+ * Creates a full-duplex pipe (as in socketpair()).
+ * Sets both ends of the pipe nonblocking.
*
* Marks both file descriptors as close-on-exec
@@ -3275,22 +3275,22 @@ _dbus_print_backtrace (void)
* @param fd1 return location for one end
* @param fd2 return location for the other end
- * @param blocking #TRUE if pair should be blocking
+ * @param blocking #TRUE if pipe should be blocking
* @param error error return
* @returns #FALSE on failure (if error is set)